@@ -14,22 +14,18 @@ import json
 import math
 import statistics
 import os
-import flask
 import sys
 
 
-filePath = ''
-groupPath = ''
-csvSavePath = ''
+filePath = '/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/logs/SimBA_dash_storage_20230202105812.h5'
+groupPath = 'None'
 
-if not len(sys.argv) > 1:
-    print("Expecting link argument.")
-else:
-    print("in p1.py link is " + sys.argv[1] + ' ' + sys.argv[2])
-    filePath = sys.argv[1]
-    groupPath = sys.argv[2]
-# SimBA script from project file path
-#   csvSavePath = sys.argv[3]
+# if not len(sys.argv) > 1:
+#     print("Expecting link argument.")
+# else:
+#     print("in p1.py link is " + sys.argv[1] + ' ' + sys.argv[2])
+#     filePath = sys.argv[1]
+#     groupPath = sys.argv[2]
 
 
 external_stylesheets = ['dash_simba_base.css', '//use.fontawesome.com/releases/v5.0.7/css/all.css']
@@ -64,6 +60,7 @@ def get_feature_data(videos, behaviors, g_categories, path, h5file):
 
         for category in g_categories:
             if category == 'VideoData':
+                print(videos)
                 video = pd.read_hdf(path, key=category + '/' + videos[0])
                 dict_features[b][category] = \
                     {column: get_probability_data(column, videos, path) for column in video.columns if '_'+b in column}
@@ -107,10 +104,12 @@ def get_categories(h5file):
         if k != 'Classifier_names' and k != 'Video_info':
             if 'VideoData' in k:
                 categories.append(k)
+                print('VideoData categories', k)
             else:
                 hf_category = h5file.get(k)
                 for key in hf_category.keys():
                     categories.append(key)
+                    print('VideoData categories 1', k)
             general_list.append(k)
     return categories, general_list
 
@@ -141,7 +140,7 @@ def get_download_path():
 # # VARIABLES AND DATA
 # # List of all videos in H5File
 video_info = pd.read_hdf(filePath, key='Video_info')
-H5list_videos = list(video_info.index)
+H5list_videos = list(video_info['Video'])
 
 # # List of Behaviors
 classifiers = pd.read_hdf(filePath, key='Classifier_names')
@@ -165,10 +164,9 @@ for group in groups_dict:
     except IndexError:
         pass
 
-# # List of videos only for probability
-list_videosInVideoData = list(hf.get('VideoData').keys())
-# # Create and store all the data to be used in dash plotly
-all_data_behaviors = get_feature_data(list_videosInVideoData, list_behaviors, general_categories, filePath, hf)
+# # Create and store all the data to be used in dash plotly in the form of a dictionary
+all_data_behaviors = get_feature_data(H5list_videos, list_behaviors, general_categories, filePath, hf)
+
 
 # # List of available and supported fonts
 FONTS = ['Verdana', 'Helvetica', 'Calibri', 'Arial', 'Arial Narrow', 'Candara', 'Geneva', 'Courier New',  'Times New Roman']
@@ -439,7 +437,7 @@ app.layout = html.Div(children=[
                                 html.Button(
                                     children=[
                                         html.I(n_clicks=0, className='fa fa-download', style={'font-size': '24px'}),
-                                        html.P('Means .CSV', style={'padding-left': '5px'})],
+                                        html.P('Group Means', style={'padding-left': '5px'})],
                                     id='download_group_data',
                                     n_clicks=0,
                                     style=set_display(groups_exist),
@@ -447,7 +445,7 @@ app.layout = html.Div(children=[
                                 html.Button(
                                     children=[
                                         html.I(n_clicks=0, className='fa fa-download', style={'font-size': '24px'}),
-                                        html.P('Videos .CSV', style={'padding-left': '5px'})],
+                                        html.P('Videos', style={'padding-left': '5px'})],
                                     id='download_data',
                                     n_clicks=0,
                                     className='five columns'),
@@ -592,7 +590,7 @@ def set_group_options(selected_group, selected_category, selected_behavior, sele
     except KeyError:
         print('No Groups')
         if 'VideoData' in selected_category:
-            return [{'label': v, 'value': v} for v in list_videosInVideoData]
+            return [{'label': v, 'value': v} for v in H5list_videos]
         else:
             try:
                 list_vid = list(all_data_behaviors[selected_behavior][selected_category][selected_feature].index)
@@ -765,7 +763,7 @@ def set_input_xrange(ind_relayout, multi_relayout, seconds, feature,
             disabled = True
 
         # Compute Seconds
-        fps = int(fps_dict['CSDS01110'])
+        fps = int(fps_dict[H5list_videos[0]])
         start_i_sec, end_i_sec = round(current_indx[0]/fps, 3), round(current_indx[1]/fps, 3)
         start_g_sec, end_g_sec = round(current_multix[0] / fps, 3), round(current_multix[1] / fps, 3)
 
@@ -1130,6 +1128,7 @@ def download(ind_click, multi_click, ind_figure, multi_figure, file_name):
 
     if 'download_data' in changed_id:
         figure = ind_figure
+
         click = ind_click
     else:
         figure = multi_figure
@@ -1141,20 +1140,18 @@ def download(ind_click, multi_click, ind_figure, multi_figure, file_name):
         if file_name is not None:
             str_name = file_name
 
-        download_df.to_csv(str_name + '.csv')
-
 # Set csv save path to csv folder
         csvSavePath = get_download_path()
-        download_df.to_csv(csvSavePath + str_name + '.csv')
-        print('Downloaded csv as ' + str_name + '.csv')
-        return ['Downloaded csv as ' + str_name + '.csv']
+        csvSavePath = os.path.join(csvSavePath, str_name + '.csv')
+        download_df.to_csv(csvSavePath)
+        # print('Downloaded csv as ' + str_name + '.csv')
+        return ['Saved ' + str_name + '.csv to Downloads']
     else:
         return []
 
 
+
+
+
 if __name__ == '__main__':
     app.run_server(debug=False)
-
-print(csvSavePath)
-
-print(filePath)
