@@ -26,6 +26,7 @@ class DeepEthogramImporter(object):
     Notes
     ----------
     `Third-party import tutorials <https://github.com/sgoldenlab/simba/blob/master/docs/third_party_annot.md>`__.
+    `Example expected input <https://github.com/sgoldenlab/simba/blob/master/misc/deep_ethogram_labels.csv>`__.
 
     Examples
     ----------
@@ -89,11 +90,11 @@ class DeepEthogramImporter(object):
                           'Exclude {} from your SimBA project or add DeepEthogram annotations for {} for video {}.'.format(clf_name, video_name, clf_name, clf_name, video_name))
                     raise ValueError()
             if len(self.annotations_df) > len(self.features_df):
-                print('SIMBA WARNING: The annotations contain data for {} frames. The pose-estimation features contain data for {} frames. '
+                print(f'SIMBA WARNING: The DEEPETHOGRAM annotations for video {video_name} contain data for {str(len(self.annotations_df))} frames. The pose-estimation features for the same video contain data for {str(len(self.features_df))} frames. '
                       'SimBA will use the annotations for the frames present in the pose-estimation data and discard the rest.')
                 self.annotations_df = self.annotations_df.head(len(self.features_df))
             if len(self.annotations_df) < len(self.features_df):
-                print('SIMBA WARNING: The annotations contain data for {} frames. The pose-estimation features contain data for {} frames. '
+                print(f'SIMBA WARNING: The DEEPETHOGRAM annotations for video {video_name} contain data for {str(len(self.annotations_df))} frames. The pose-estimation features for the same video contain data for {str(len(self.features_df))} frames. '
                       'SimBA expects the annotations and pose-estimation data to contain an equal number of frames. SimBA will assume that '
                       'the un-annotated frames have no behaviors present.')
                 padding = pd.DataFrame([[0] * (len(self.features_df) - len(self.annotations_df))], columns=self.annotations_df)
