@@ -1,7 +1,9 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 from simba.read_config_unit_tests import (read_config_entry,
-                                          read_config_file)
+                                          read_config_file,
+                                          check_if_filepath_list_is_empty,
+                                          read_project_path_and_file_type)
 import os, glob
 from simba.misc_tools import (check_multi_animal_status,
                               get_video_meta_data,
@@ -11,6 +13,8 @@ from simba.drop_bp_cords import (getBpNames,
                                  get_fn_ext,
                                  createColorListofList,
                                  create_body_part_dictionary)
+from simba.enums import Paths, ReadConfig, Dtypes
+from datetime import datetime
 import itertools
 import pandas as pd
 import numpy as np
@@ -73,14 +77,14 @@ class MADLC_Importer(object):
         self.smoothing_settings = smoothing_settings
         self.input_folder = data_folder
         self.id_lst = id_lst
-        self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='str')
-        self.animal_cnt = read_config_entry(self.config, 'General settings', 'animal_no', 'int')
+        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
+        self.animal_cnt = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.ANIMAL_CNT.value, Dtypes.INT.value)
         self.video_folder = os.path.join(self.project_path, 'videos')
+        self.import_log_path = os.path.join(self.project_path, 'logs', f'data_import_log_{datetime.now().strftime("%Y%m%d%H%M%S")}.csv')
         self.videos_in_project = self.__find_all_videos_in_project(self.video_folder)
         self.videos_in_project_lower_case = [os.path.basename(x).lower() for x in self.videos_in_project]
-        self.save_folder = os.path.join(self.project_path, 'csv', 'input_csv')
-        self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
-        self.pose_setting = read_config_entry(self.config, 'create ensemble settings', 'pose_estimation_body_parts', data_type='str')
+        self.save_folder = os.path.join(self.project_path, Paths.INPUT_CSV.value)
+        self.pose_setting = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.POSE_SETTING.value, data_type=Dtypes.STR.value)
         if file_type == 'skeleton': dlc_file_ending, dlc_filtered_file_ending = 'sk.h5', 'sk_filtered.h5'
         elif file_type == 'box': dlc_file_ending, dlc_filtered_file_ending = 'bx.h5', 'bx_filtered.h5'
         elif file_type == 'ellipse': dlc_file_ending, dlc_filtered_file_ending = 'el.h5', 'el_filtered.h5'
@@ -103,9 +107,8 @@ class MADLC_Importer(object):
             for currXcol, currYcol, currPcol in zip(self.animal_bp_dict[animal]['X_bps'], self.animal_bp_dict[animal]['Y_bps'], self.animal_bp_dict[animal]['P_bps']):
                 self.bp_lst.extend((animal + '_' + currXcol, animal + '_' + currYcol, animal + '_' + currPcol))
 
-        if len(self.files_found) == 0:
-            print(('SIMBA ERROR: Found 0 files in {} path that satisfy the criterion for maDLC {} filetype. SimBA detected {} other files within in directory'.format(self.input_folder, file_type, str(len(self.files_in_folder)))))
-            raise FileNotFoundError('SIMBA ERROR: Found 0 files in {} path that satisfy the criterion for maDLC {} filetype. SimBA detected {} other files within in directory'.format(self.input_folder, file_type, str(len(self.files_in_folder))))
+        check_if_filepath_list_is_empty(filepaths=self.files_found,
+                                        error_msg='SIMBA ERROR: Found 0 files in {} path that satisfy the criterion for maDLC {} filetype. SimBA detected {} other files within in directory'.format(self.input_folder, file_type, str(len(self.files_in_folder))))
         print('Importing {} file(s)...'.format(str(len(self.files_found))))
 
     def __find_all_videos_in_project(self, folder_path=None):
@@ -363,6 +366,7 @@ class MADLC_Importer(object):
 
         """
 
+        import_log = pd.DataFrame(columns=['VIDEO', 'IMPORT_TIME', 'IMPORT_SOURCE', 'INTERPOLATION_SETTING', 'SMOOTHING_SETTING'])
         for file_cnt, file_path in enumerate(self.files_found):
             self.add_spacer = 2
             _, self.file_name, _ = get_fn_ext(file_path)
@@ -395,10 +399,25 @@ class MADLC_Importer(object):
                 self.__run_interpolation()
             if self.smoothing_settings['Method'] != 'None':
                 self.__run_smoothing()
+            import_log.loc[len(import_log)] = [self.file_name,
+                                               datetime.now().strftime('%Y%m%d%H%M%S'),
+                                               'MADLC',
+                                               str(self.interpolation_settings),
+                                               str(self.smoothing_settings)]
             print('SimBA import of file {} complete!'.format(self.file_name))
 
+        import_log.to_csv(self.import_log_path)
         print('SIMBA COMPLETE: {} files imported to your SimBA project. Imported files are located in the project_folder/csv/input_csv directory.'.format(str(len(self.files_found))))
 
+# test = MADLC_Importer(config_path=r'/Users/simon/Desktop/envs/troubleshooting/two_black_animals/project_folder/project_config.ini',
+#                    data_folder=r'/Users/simon/Desktop/envs/troubleshooting/two_black_animals/h5',
+#                    file_type='ellipse',
+#                    id_lst=['Simon', 'JJ'],
+#                    interpolation_settings='Body-parts: Nearest',
+#                    smoothing_settings = {'Method': 'Savitzky Golay', 'Parameters': {'Time_window': '200'}})
+# test.import_data()
+
+
 
 # test = MADLC_Importer(config_path=r'/Users/simon/Desktop/troubleshooting/B1-MS_US/project_folder/project_config.ini',
 #                    data_folder=r'/Users/simon/Desktop/troubleshooting/B1-MS_US/el_import/other_2',
@@ -415,11 +434,3 @@ class MADLC_Importer(object):
 #                    interpolation_settings='None',
 #                    smoothing_settings={'Method': 'None', 'Parameters': {'Time_window': '200'}})
 # test.import_data()
-
-# test = MADLC_Importer(config_path=r'/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini',
-#                    data_folder=r'/Users/simon/Desktop/troubleshooting/train_model_project/import',
-#                    file_type='ellipse',
-#                    id_lst=['Simon', 'JJ'],
-#                    interpolation_settings='Body-parts: Nearest',
-#                    smoothing_settings = {'Method': 'Savitzky Golay', 'Parameters': {'Time_window': '200'}})
-# test.import_data()
