@@ -128,6 +128,10 @@ class Options(Enum):
     PERFORM_FLAGS = ['yes', True, 'True']
     RUN_OPTIONS_FLAGS = ['yes', True, 'True', 'False', 'no', False]
     SCALER_NAMES = ['MIN-MAX', 'STANDARD', 'QUANTILE']
+    HEATMAP_SHADING_OPTIONS = ['gouraud', 'flat']
+    HEATMAP_BIN_SIZE_OPTIONS = ['10×10', '20×20', '40×40', '80×80', '160×160', '320×320', '640×640', '1280×1280']
+
+
     UNSUPERVISED_FEATURE_OPTIONS = ['INCLUDE FEATURE DATA (ORIGINAL)', 'INCLUDE FEATURES (SCALED)', 'EXCLUDE FEATURE DATA']
     TIMEBINS_MEASURMENT_OPTIONS = ['First occurance (s)', 'Event count', 'Total event duration (s)',
                                               'Mean event duration (s)', 'Median event duration (s)',
