@@ -11,7 +11,7 @@ from copy import deepcopy
 import math
 from collections import defaultdict
 import scipy
-from simba.features_scripts.feature_extraction_mixin import FeatureExtractionMixin
+from simba.mixins.feature_extraction_mixin import FeatureExtractionMixin
 
 class ExtractFeaturesFrom4bps(FeatureExtractionMixin):
     """
