@@ -11,7 +11,7 @@ import math
 from scipy.spatial import ConvexHull
 from collections import defaultdict
 import scipy
-from simba.features_scripts.feature_extraction_mixin import FeatureExtractionMixin
+from simba.mixins.feature_extraction_mixin import FeatureExtractionMixin
 
 class ExtractFeaturesFrom7bps(FeatureExtractionMixin):
     
