@@ -19,8 +19,7 @@ import scipy
 from collections import defaultdict
 from joblib import Parallel, delayed
 import time
-from simba.features_scripts.feature_extraction_mixin import FeatureExtractionMixin
-
+from simba.mixins.feature_extraction_mixin import FeatureExtractionMixin
 
 class ExtractFeaturesFrom8bps(FeatureExtractionMixin):
     """
