@@ -12,7 +12,7 @@ from collections import defaultdict
 import scipy
 from joblib import Parallel, delayed
 import time
-from simba.features_scripts.feature_extraction_mixin import FeatureExtractionMixin
+from simba.mixins.feature_extraction_mixin import FeatureExtractionMixin
 
 class ExtractFeaturesFrom8bps2Animals(FeatureExtractionMixin):
     """
