@@ -1,8 +1,13 @@
-from simba.read_config_unit_tests import read_config_file, read_config_entry
+from simba.read_config_unit_tests import (read_config_file,
+                                          read_config_entry)
 import os
 import subprocess, shutil
-from simba.misc_tools import get_video_meta_data, remove_a_folder
+from simba.misc_tools import (get_video_meta_data,
+                              remove_a_folder,
+                              get_fn_ext,
+                              SimbaTimer)
 from datetime import datetime
+from simba.enums import Paths, ReadConfig
 
 
 class FrameMergererFFmpeg(object):
@@ -36,15 +41,18 @@ class FrameMergererFFmpeg(object):
                  video_height: int or None,
                  video_width: int or None):
 
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
         if config_path is not None:
             self.config_path, self.config = config_path, read_config_file(ini_path=config_path)
-            self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='str')
-            self.output_dir = os.path.join(self.project_path, 'frames', 'output', 'merged')
-            self.temp_dir = os.path.join(self.project_path, 'frames', 'output', 'merged', 'temp')
-            self.output_path = os.path.join(self.project_path, 'frames', 'output', 'merged', 'merged_video_{}.mp4'.format(str(self.datetime)))
+            self.project_path = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value, data_type=ReadConfig.FOLDER_PATH.value)
+            self.output_dir = os.path.join(self.project_path, Paths.CONCAT_VIDEOS_DIR.value)
+            self.temp_dir = os.path.join(self.project_path, Paths.CONCAT_VIDEOS_DIR.value, 'temp')
+            self.output_path = os.path.join(self.project_path, Paths.CONCAT_VIDEOS_DIR.value, 'merged_video_{}.mp4'.format(str(self.datetime)))
         else:
-            self.output_dir = os.path.basename(list(frame_types.items())[0])
+            self.file_path = list(frame_types.values())[0]
+            self.output_dir, ss, df = get_fn_ext(filepath=self.file_path)
             self.temp_dir = os.path.join(self.output_dir, 'temp')
             self.output_path = os.path.join(self.output_dir, 'merged_video_{}.mp4'.format(str(self.datetime)))
 
@@ -60,9 +68,9 @@ class FrameMergererFFmpeg(object):
         elif concat_type == 'vertical':
             self.__vertical_concatenator(out_path=self.output_path, frames_dict=self.frame_types, final_img=True)
         elif concat_type == 'mosaic':
-            self.mosaic_concatenator(output_path=self.output_path, frames_dict=self.frame_types, final_img=True)
+            self.__mosaic_concatenator(output_path=self.output_path, frames_dict=self.frame_types, final_img=True)
         elif concat_type == 'mixed_mosaic':
-            self.mixed_mosaic_concatenator()
+            self.__mixed_mosaic_concatenator()
         remove_a_folder(folder_dir=self.temp_dir)
 
     def __resize_height(self, new_height: int):
@@ -95,7 +103,6 @@ class FrameMergererFFmpeg(object):
         """ Helper to change the width and height videos"""
 
         for video_cnt, (video_type, video_path) in enumerate(self.frame_types.items()):
-            print(video_path)
             video_meta_data = get_video_meta_data(video_path=video_path)
             out_path = os.path.join(self.temp_dir, video_type + '.mp4')
             if video_meta_data['height'] != new_width:
@@ -113,7 +120,11 @@ class FrameMergererFFmpeg(object):
         subprocess.call(cmd, shell=True, stdout=subprocess.PIPE)
         self.frame_types['blank'] = self.blank_path
 
-    def horizontal_concatenator(self, frames_dict: dict, out_path: str, include_resize=True, final_img=True):
+    def __horizontal_concatenator(self,
+                                  frames_dict: dict,
+                                  out_path: str,
+                                  include_resize=True,
+                                  final_img=True):
         """ Helper to horizontally concatenate N videos """
 
         if include_resize: self.__resize_height(new_height=self.video_height)
@@ -123,9 +134,15 @@ class FrameMergererFFmpeg(object):
         cmd = 'ffmpeg -y{} -filter_complex hstack=inputs={} -vsync 2 "{}"'.format(video_path_str, str(len(frames_dict.keys())), out_path)
         print('Concatenating (horizontal) {} videos...'.format(str(len(frames_dict.keys()))))
         subprocess.call(cmd, shell=True, stdout=subprocess.PIPE)
-        if final_img: print('SIMBA COMPLETE: Merged video saved at {}'.format(out_path))
+        if final_img:
+            self.timer.stop_timer()
+            print('SIMBA COMPLETE: Merged video saved at {} (elapsed time: {}s)'.format(out_path, self.timer.elapsed_time_str))
 
-    def __vertical_concatenator(self, frames_dict: dict, out_path: str, include_resize=True, final_img=True):
+    def __vertical_concatenator(self,
+                                frames_dict: dict,
+                                out_path: str,
+                                include_resize=True,
+                                final_img=True):
         """ Helper to vertically concatenate N videos """
 
         if include_resize: self.__resize_width(new_width=self.video_width)
@@ -135,9 +152,14 @@ class FrameMergererFFmpeg(object):
         cmd = 'ffmpeg -y{} -filter_complex vstack=inputs={} -vsync 2 "{}"'.format(video_path_str, str(len(frames_dict.keys())), out_path)
         print('Concatenating (vertical) {} videos...'.format(str(len(frames_dict.keys()))))
         subprocess.call(cmd, shell=True, stdout=subprocess.PIPE)
-        if final_img: print('SIMBA COMPLETE: Merged video saved at {}'.format(out_path))
+        if final_img:
+            self.timer.stop_timer()
+            print('SIMBA COMPLETE: Merged video saved at {} (elapsed time: {}s)'.format(out_path, self.timer.elapsed_time_str))
 
-    def mosaic_concatenator(self, frames_dict: dict, output_path: str, final_img:bool):
+    def __mosaic_concatenator(self,
+                            frames_dict: dict,
+                            output_path: str,
+                            final_img:bool):
         self.__resize_width_and_height(new_width=self.video_width, new_height=self.video_height)
         if not self.even_bool:
             self.__create_blank_video()
@@ -150,12 +172,12 @@ class FrameMergererFFmpeg(object):
         frames_dict = {'upper': os.path.join(self.temp_dir, 'upper.mp4'), 'lower': os.path.join(self.temp_dir, 'lower.mp4')}
         self.__vertical_concatenator(frames_dict=frames_dict, out_path=output_path, include_resize=False, final_img=final_img)
 
-    def mixed_mosaic_concatenator(self):
+    def __mixed_mosaic_concatenator(self):
         large_mosaic_dict = {str(list(self.frame_types.keys())[0]): str(list(self.frame_types.values())[0])}
         del self.frame_types[str(list(self.frame_types.keys())[0])]
         self.even_bool = (len(self.frame_types.keys()) % 2) == 0
         output_path = os.path.join(self.temp_dir, 'mosaic.mp4')
-        self.mosaic_concatenator(frames_dict=self.frame_types, output_path=output_path, final_img=False)
+        self.__mosaic_concatenator(frames_dict=self.frame_types, output_path=output_path, final_img=False)
         self.frame_types = large_mosaic_dict
         self.__resize_height(new_height=get_video_meta_data(video_path=output_path)['height'])
         self.frame_types = {str(list(large_mosaic_dict.keys())[0]): os.path.join(self.temp_dir, str(list(large_mosaic_dict.keys())[0]) + '.mp4'), 'mosaic': os.path.join(self.temp_dir, 'mosaic.mp4')}
