@@ -10,7 +10,7 @@ from simba.misc_tools import (get_fn_ext,
                               SimbaTimer,
                               remove_a_folder,
                               concatenate_videos_in_folder)
-from simba.misc_visualizations import make_heatmap_plot
+from simba.misc_visualizations import make_clf_heatmap_plot
 from simba.rw_dfs import read_df
 import numpy as np
 import os
@@ -40,7 +40,6 @@ def _heatmap_multiprocessor(data: np.array,
                             size: tuple):
 
     group = int(data[0][0][1])
-
     if video_setting:
         fourcc = cv2.VideoWriter_fourcc(*Formats.MP4_CODEC.value)
         video_save_path = os.path.join(video_temp_dir, '{}.mp4'.format(str(group)))
@@ -49,38 +48,15 @@ def _heatmap_multiprocessor(data: np.array,
     for i in range(data.shape[0]):
         frame_id = int(data[i, 0, 0])
         frm_data = data[i, :, 2:]
-        cum_df = pd.DataFrame(frm_data).reset_index()
-        cum_df = cum_df.melt(id_vars='index', value_vars=None, var_name=None, value_name='seconds',
-                             col_level=None).rename(columns={'index': 'vertical_idx', 'variable': 'horizontal_idx'})
-        cum_df['color'] = (cum_df['seconds'].astype(float) / float(max_scale)).round(2).clip(upper=100)
-        color_array = np.zeros((len(cum_df['vertical_idx'].unique()), len(cum_df['horizontal_idx'].unique())))
-        for i in range(color_array.shape[0]):
-            for j in range(color_array.shape[1]):
-                value = cum_df["color"][(cum_df["horizontal_idx"] == j) & (cum_df["vertical_idx"] == i)].values[0]
-                color_array[i, j] = value
-        fig = plt.figure()
-        im_ratio = color_array.shape[0] / color_array.shape[1]
-        plt.pcolormesh(color_array, shading=style_attr['shading'], cmap=style_attr['palette'], rasterized=True, alpha=1, vmin=0.0, vmax=float(max_scale))
-        plt.gca().invert_yaxis()
-        plt.xticks([])
-        plt.yticks([])
-        plt.axis('off')
-        plt.tick_params(axis='both', which='both', length=0)
-        cb = plt.colorbar(pad=0.0, fraction=0.023 * im_ratio)
-        cb.ax.tick_params(size=0)
-        cb.outline.set_visible(False)
-        cb.set_label('{} (seconds)'.format(clf_name), rotation=270, labelpad=10)
-        plt.tight_layout()
-        plt.gca().set_aspect(aspect_ratio)
-        canvas = FigureCanvas(fig)
-        canvas.draw()
-        mat = np.array(canvas.renderer._renderer)
-        img = cv2.cvtColor(mat, cv2.COLOR_RGB2BGR)
-        img = cv2.resize(img, (size[1], size[0]))
-        img = np.uint8(img)
-        plt.close()
+        img = make_clf_heatmap_plot(frm_data=frm_data,
+                              max_scale=max_scale,
+                              palette=style_attr['palette'],
+                              aspect_ratio=aspect_ratio,
+                              shading=style_attr['shading'],
+                              clf_name=clf_name,
+                              img_size=size,
+                              final_img=False)
         print('Heatmap frame created: {}, Video: {}, Processing core: {}'.format(str(frame_id+1), video_name, str(group+1)))
-
         if video_setting:
             video_writer.write(img)
 
@@ -128,7 +104,7 @@ class HeatMapperClfMultiprocess(object):
     Examples
     -----
 
-    >>> heat_mapper_clf = HeatMapperClf(config_path='MyConfigPath', final_img_setting=False, video_setting=True, frame_setting=False, bin_size=50, palette='jet', bodypart='Nose_1', clf_name='Attack', max_scale=20)
+    >>> heat_mapper_clf = HeatMapperClfMultiprocess(config_path='MyConfigPath', final_img_setting=False, video_setting=True, frame_setting=False, bin_size=50, palette='jet', bodypart='Nose_1', clf_name='Attack', max_scale=20)
     >>> heat_mapper_clf.create_heatmaps()
     """
 
@@ -265,7 +241,6 @@ class HeatMapperClfMultiprocess(object):
             _, self.video_name, _ = get_fn_ext(file_path)
             self.video_info, self.px_per_mm, self.fps = read_video_info(vid_info_df=self.vid_info_df, video_name=self.video_name)
             self.width, self.height = int(self.video_info['Resolution_width'].values[0]), int(self.video_info['Resolution_height'].values[0])
-
             self.save_frame_folder_dir = os.path.join(self.out_parent_dir, self.video_name + '_' + self.clf_name)
             self.video_folder = os.path.join(self.out_parent_dir, self.video_name + '_' + self.clf_name)
             self.temp_folder = os.path.join(self.out_parent_dir, self.video_name + '_' + self.clf_name, 'temp')
@@ -294,14 +269,15 @@ class HeatMapperClfMultiprocess(object):
                 self.max_scale = self.__calculate_max_scale(clf_array=clf_array)
 
             if self.final_img_setting:
-                make_heatmap_plot(data_arr=clf_array,
-                                  max_scale=self.max_scale,
-                                  palette=self.palette,
-                                  aspect_ratio=aspect_ratio,
-                                  file_name=os.path.join(self.out_parent_dir, self.video_name + '_final_frm.png'),
-                                  shading=self.shading,
-                                  clf_name=self.clf_name,
-                                  img_size=(self.width, self.height))
+                make_clf_heatmap_plot(frm_data=clf_array[-1, :, :],
+                                      max_scale=self.max_scale,
+                                      palette=self.palette,
+                                      aspect_ratio=aspect_ratio,
+                                      file_name=os.path.join(self.out_parent_dir, self.video_name + '_final_frm.png'),
+                                      shading=self.shading,
+                                      clf_name=self.clf_name,
+                                      img_size=(self.height, self.width),
+                                      final_img=True)
 
             if self.video_setting or self.frame_setting:
                 frame_arrays = np.array_split(clf_array, self.core_cnt)
@@ -313,7 +289,7 @@ class HeatMapperClfMultiprocess(object):
                 frm_per_core = frame_arrays[0].shape[0]
 
                 print('Creating heatmaps, multiprocessing (chunksize: {}, cores: {})...'.format(str(self.chunksize), str(self.core_cnt)))
-                with multiprocessing.Pool(self.core_cnt, maxtasksperchild=2) as pool:
+                with multiprocessing.Pool(self.core_cnt, maxtasksperchild=self.maxtasksperchild) as pool:
                     constants = functools.partial(_heatmap_multiprocessor,
                                                   video_setting=self.video_setting,
                                                   frame_setting=self.frame_setting,
@@ -344,7 +320,7 @@ class HeatMapperClfMultiprocess(object):
 
 
 
-# test = HeatMapperClfMultiprocess(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini',
+# test = HeatMapperClfMultiprocess(config_path='/Users/simon/Desktop/envs/troubleshooting/Two_animals_16bps/project_folder/project_config.ini',
 #                      style_attr = {'palette': 'jet', 'shading': 'gouraud', 'bin_size': 100, 'max_scale': 'auto'},
 #                      final_img_setting=False,
 #                      video_setting=True,
@@ -352,6 +328,6 @@ class HeatMapperClfMultiprocess(object):
 #                      bodypart='Nose_1',
 #                      clf_name='Attack',
 #                                core_cnt=5,
-#                      files_found=['/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/csv/machine_results/Together_1.csv'])
+#                      files_found=['/Users/simon/Desktop/envs/troubleshooting/Two_animals_16bps/project_folder/csv/machine_results/Together_3.csv'])
 # test.create_heatmaps()
 
