@@ -33,8 +33,12 @@ import platform
 import pickle
 import pathlib
 from datetime import datetime
+import sys
+import importlib
+import ast
 import simba
 
+
 def get_video_meta_data(video_path: str):
     """
     Helper to read video meta data (fps, resolution, frame cnt etc.) from video file.
@@ -73,6 +77,7 @@ def get_video_meta_data(video_path: str):
     video_data['video_length_s'] = int(video_data['frame_count'] / video_data['fps'])
     return video_data
 
+
 def check_directionality_viable(animal_bp_dict: dict):
     """
     Helper to check if it is possible to calculate ``directionality`` statistics (i.e., nose, and ear coordinates from
@@ -143,7 +148,8 @@ def check_multi_animal_status(config: configparser.ConfigParser,
         multi_animal_status = False
 
     else:
-        multi_animal_id_str = read_config_entry(config=config, section='Multi animal IDs',option='id_list',data_type='str')
+        multi_animal_id_str = read_config_entry(config=config, section='Multi animal IDs', option='id_list',
+                                                data_type='str')
         multi_animal_id_lst = [x.lstrip() for x in multi_animal_id_str.split(",")]
         multi_animal_id_lst = [x for x in multi_animal_id_lst if x != 'None']
         if (no_animals > 1) and (len(multi_animal_id_lst) > 1):
@@ -189,9 +195,9 @@ def line_length(p: list,
     Qy = np.abs(q[1] - M[1])
     Nx = np.abs(n[0] - M[0])
     Ny = np.abs(n[1] - M[1])
-    Ph = np.sqrt(Px*Px + Py*Py)
-    Qh = np.sqrt(Qx*Qx + Qy*Qy)
-    Nh = np.sqrt(Nx*Nx + Ny*Ny)
+    Ph = np.sqrt(Px * Px + Py * Py)
+    Qh = np.sqrt(Qx * Qx + Qy * Qy)
+    Nh = np.sqrt(Nx * Nx + Ny * Ny)
     if (Nh < Ph and Nh < Qh and Qh < Ph):
         coord.extend((q[0], q[1]))
         return True, coord
@@ -201,6 +207,7 @@ def line_length(p: list,
     else:
         return False, coord
 
+
 def get_number_of_header_columns_in_df(df: pd.DataFrame):
     for i in range(len(df)):
         try:
@@ -212,7 +219,6 @@ def get_number_of_header_columns_in_df(df: pd.DataFrame):
     raise ValueError()
 
 
-
 @jit(nopython=True)
 def line_length_numba(left_ear_array: np.array,
                       right_ear_array: np.array,
@@ -251,7 +257,7 @@ def line_length_numba(left_ear_array: np.array,
         if (Nh < Ph and Nh < Qh and Qh < Ph):
             results_array[frame_no] = [0, right_ear_array[frame_no][0], right_ear_array[frame_no][1], True]
         elif (Nh < Ph and Nh < Qh and Ph < Qh):
-            results_array[frame_no] = [1, left_ear_array[frame_no][0],  left_ear_array[frame_no][1], True]
+            results_array[frame_no] = [1, left_ear_array[frame_no][0], left_ear_array[frame_no][1], True]
         else:
             results_array[frame_no] = [2, -1, -1, False]
     return results_array
@@ -282,7 +288,7 @@ def line_length_numba_to_static_location(left_ear_array: np.array,
     results_array: np.array
     """
 
-    results_array =  np.zeros((left_ear_array.shape[0], 4))
+    results_array = np.zeros((left_ear_array.shape[0], 4))
     for frame_no in range(results_array.shape[0]):
         Px = np.abs(left_ear_array[frame_no][0] - target_array[0])
         Py = np.abs(left_ear_array[frame_no][1] - target_array[1])
@@ -296,7 +302,7 @@ def line_length_numba_to_static_location(left_ear_array: np.array,
         if (Nh < Ph and Nh < Qh and Qh < Ph):
             results_array[frame_no] = [0, right_ear_array[frame_no][0], right_ear_array[frame_no][1], True]
         elif (Nh < Ph and Nh < Qh and Ph < Qh):
-            results_array[frame_no] = [1, left_ear_array[frame_no][0],  left_ear_array[frame_no][1], True]
+            results_array[frame_no] = [1, left_ear_array[frame_no][0], left_ear_array[frame_no][1], True]
         else:
             results_array[frame_no] = [2, -1, -1, False]
 
@@ -333,7 +339,8 @@ def find_video_of_file(video_dir: str,
             return_path = file_path
 
     if return_path is None:
-        print('SIMBA WARNING: SimBA could not find a video file representing {} in the project video directory'.format(str(filename)))
+        print('SIMBA WARNING: SimBA could not find a video file representing {} in the project video directory'.format(
+            str(filename)))
     return return_path
 
 
@@ -366,12 +373,15 @@ def smooth_data_gaussian(config: configparser.ConfigParser,
     try:
         time_window_parameter = int(time_window_parameter)
     except:
-        print('Gaussian smoothing failed for video {}. Time window parameter {} can not be interpreted as an integer.'.format(str(os.path.basename(file_path)), str(time_window_parameter)))
+        print(
+            'Gaussian smoothing failed for video {}. Time window parameter {} can not be interpreted as an integer.'.format(
+                str(os.path.basename(file_path)), str(time_window_parameter)))
     _, filename, _ = get_fn_ext(file_path)
     project_dir = config.get(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value)
     video_dir = os.path.join(project_dir, 'videos')
     video_file_path = find_video_of_file(video_dir, filename)
-    file_format = read_config_entry(config=config, section=ReadConfig.GENERAL_SETTINGS.value, option=ReadConfig.FILE_TYPE.value, data_type=Dtypes.STR.value, default_value='csv')
+    file_format = read_config_entry(config=config, section=ReadConfig.GENERAL_SETTINGS.value,
+                                    option=ReadConfig.FILE_TYPE.value, data_type=Dtypes.STR.value, default_value='csv')
     cap = cv2.VideoCapture(video_file_path)
     video_fps = int(cap.get(cv2.CAP_PROP_FPS))
     pose_df = read_df(file_path=file_path, file_type=file_format)
@@ -381,7 +391,7 @@ def smooth_data_gaussian(config: configparser.ConfigParser,
     else:
         idx_names = ['scorer', 'individuals', 'bodyparts', 'coords']
     if file_format == 'csv':
-        pose_df = pd.read_csv(file_path, header=list(range(header_cols+1)), index_col=0)
+        pose_df = pd.read_csv(file_path, header=list(range(header_cols + 1)), index_col=0)
     elif file_format == 'parquet':
         pose_df = pd.read_parquet(file_path)
 
@@ -390,7 +400,8 @@ def smooth_data_gaussian(config: configparser.ConfigParser,
     new_df.columns.names = idx_names
 
     for c in new_df:
-        new_df[c] = new_df[c].rolling(window=int(frames_in_time_window), win_type='gaussian', center=True).mean(std=5).fillna(new_df[c])
+        new_df[c] = new_df[c].rolling(window=int(frames_in_time_window), win_type='gaussian', center=True).mean(
+            std=5).fillna(new_df[c])
         new_df[c] = new_df[c].abs()
 
     if file_format == 'csv':
@@ -401,6 +412,7 @@ def smooth_data_gaussian(config: configparser.ConfigParser,
 
     print('Gaussian smoothing complete for file {}'.format(filename), '...')
 
+
 def smooth_data_savitzky_golay(config: configparser.ConfigParser,
                                file_path: str,
                                time_window_parameter=int):
@@ -447,7 +459,7 @@ def smooth_data_savitzky_golay(config: configparser.ConfigParser,
     else:
         idx_names = ['scorer', 'individuals', 'bodyparts', 'coords']
     if file_format == 'csv':
-        pose_df = pd.read_csv(file_path, header=list(range(header_cols+1)), index_col=0)
+        pose_df = pd.read_csv(file_path, header=list(range(header_cols + 1)), index_col=0)
     elif file_format == 'parquet':
         pose_df = pd.read_parquet(file_path)
     frames_in_time_window = int(time_window_parameter / (1000 / video_fps))
@@ -459,16 +471,18 @@ def smooth_data_savitzky_golay(config: configparser.ConfigParser,
     new_df.columns.names = idx_names
 
     for c in new_df:
-        new_df[c] = savgol_filter(x=new_df[c].to_numpy(), window_length=frames_in_time_window, polyorder=3, mode='nearest')
+        new_df[c] = savgol_filter(x=new_df[c].to_numpy(), window_length=frames_in_time_window, polyorder=3,
+                                  mode='nearest')
         new_df[c] = new_df[c].abs()
     if file_format == 'csv':
-        save_df(new_df,file_format, file_path)
+        save_df(new_df, file_format, file_path)
     elif file_format == 'parquet':
         table = pa.Table.from_pandas(new_df)
         pq.write_table(table, file_path)
 
     print('Savitzky-Golay smoothing complete for file {}'.format(filename), '...')
 
+
 def add_missing_ROI_cols(shape_df: pd.DataFrame):
     """
     Helper to add missing ROI definitions in ROI info dataframes created by the first version of the SimBA ROI
@@ -493,6 +507,7 @@ def add_missing_ROI_cols(shape_df: pd.DataFrame):
 
     return shape_df
 
+
 def get_file_path_parts(file_path: str):
     """
     Helper to split file path into three components: (i) directory, (ii) file name, and (iii) file extension.
@@ -514,6 +529,7 @@ def get_file_path_parts(file_path: str):
     extension = Path(file_path).suffix
     return file_directory, file_name, extension
 
+
 def create_gantt_img(bouts_df: pd.DataFrame,
                      clf_name: str,
                      image_index: int,
@@ -541,7 +557,6 @@ def create_gantt_img(bouts_df: pd.DataFrame,
 
     """
 
-
     fig, ax = plt.subplots()
     fig.suptitle(gantt_img_title, fontsize=24)
     relRows = bouts_df.loc[bouts_df['End_frame'] <= image_index]
@@ -572,6 +587,7 @@ def create_gantt_img(bouts_df: pd.DataFrame,
 
     return open_cv_image
 
+
 def resize_gantt(gantt_img: np.array,
                  img_height: int):
     """
@@ -604,7 +620,6 @@ def plug_holes_shortest_bout(data_df: pd.DataFrame,
         Dataframe where behavior bouts with invalid lengths have been removed (< shortest_bout).
     """
 
-
     frames_to_plug = int(int(fps) * int(shortest_bout) / 1000)
     frames_to_plug_lst = list(range(1, frames_to_plug + 1))
     frames_to_plug_lst.reverse()
@@ -625,24 +640,24 @@ def plug_holes_shortest_bout(data_df: pd.DataFrame,
     for currPattern in fill_patterns:
         n_obs = len(currPattern)
         data_df['rolling_match'] = (data_df[clf_name].rolling(window=n_obs, min_periods=n_obs)
-                                     .apply(lambda x: (x == currPattern).all())
-                                     .mask(lambda x: x == 0)
-                                     .bfill(limit=n_obs - 1)
-                                     .fillna(0)
-                                     .astype(bool)
-                                     )
+                                    .apply(lambda x: (x == currPattern).all())
+                                    .mask(lambda x: x == 0)
+                                    .bfill(limit=n_obs - 1)
+                                    .fillna(0)
+                                    .astype(bool)
+                                    )
         data_df.loc[data_df['rolling_match'] == True, clf_name] = 1
         data_df = data_df.drop(['rolling_match'], axis=1)
 
     for currPattern in remove_patterns:
         n_obs = len(currPattern)
         data_df['rolling_match'] = (data_df[clf_name].rolling(window=n_obs, min_periods=n_obs)
-                                     .apply(lambda x: (x == currPattern).all())
-                                     .mask(lambda x: x == 0)
-                                     .bfill(limit=n_obs - 1)
-                                     .fillna(0)
-                                     .astype(bool)
-                                     )
+                                    .apply(lambda x: (x == currPattern).all())
+                                    .mask(lambda x: x == 0)
+                                    .bfill(limit=n_obs - 1)
+                                    .fillna(0)
+                                    .astype(bool)
+                                    )
         data_df.loc[data_df['rolling_match'] == True, clf_name] = 0
         data_df = data_df.drop(['rolling_match'], axis=1)
 
@@ -670,8 +685,6 @@ def get_bouts_for_gantt(data_df: pd.DataFrame,
         Holding the start time, end time, end frame, bout time etc of each classified bout.
     """
 
-
-
     boutsList, nameList, startTimeList, endTimeList, endFrameList = [], [], [], [], []
     groupDf = pd.DataFrame()
     v = (data_df[clf_name] != data_df[clf_name].shift()).cumsum()
@@ -690,7 +703,9 @@ def get_bouts_for_gantt(data_df: pd.DataFrame,
         nameList.append(clf_name)
         endFrameList.append(endFrame)
 
-    return pd.DataFrame(list(zip(nameList, startTimeList, endTimeList, endFrameList, boutsList)), columns=['Event', 'Start_time', 'End Time', 'End_frame', 'Bout_time'])
+    return pd.DataFrame(list(zip(nameList, startTimeList, endTimeList, endFrameList, boutsList)),
+                        columns=['Event', 'Start_time', 'End Time', 'End_frame', 'Bout_time'])
+
 
 def read_config_file(ini_path: str):
     """ Helper to read SimBA project config ini file"""
@@ -698,13 +713,15 @@ def read_config_file(ini_path: str):
     try:
         config.read(str(ini_path))
     except MissingSectionHeaderError:
-        raise MissingSectionHeaderError('ERROR:  Not a valid project_config file. Please check the project_config.ini path.')
+        raise MissingSectionHeaderError(
+            'ERROR:  Not a valid project_config file. Please check the project_config.ini path.')
     return config
 
+
 def create_single_color_lst(pallete_name: str,
                             increments: int,
-                            as_rgb_ratio: bool=False,
-                            as_hex: bool=False):
+                            as_rgb_ratio: bool = False,
+                            as_hex: bool = False):
     """
     Helper to create a color palette of bgr colors in a list.
     Parameters
@@ -733,6 +750,7 @@ def create_single_color_lst(pallete_name: str,
         color_lst.append(rgb)
     return color_lst
 
+
 def detect_bouts(data_df: pd.DataFrame,
                  target_lst: list,
                  fps: int):
@@ -775,7 +793,9 @@ def detect_bouts(data_df: pd.DataFrame,
             endFrameList.append(endFrame)
             startFrameLst.append(bout_start_frm)
 
-    return pd.DataFrame(list(zip(nameList, startTimeList, endTimeList, startFrameLst, endFrameList, boutsList)), columns=['Event', 'Start_time', 'End Time', 'Start_frame', 'End_frame', 'Bout_time'])
+    return pd.DataFrame(list(zip(nameList, startTimeList, endTimeList, startFrameLst, endFrameList, boutsList)),
+                        columns=['Event', 'Start_time', 'End Time', 'Start_frame', 'End_frame', 'Bout_time'])
+
 
 def find_core_cnt():
     """
@@ -792,20 +812,23 @@ def find_core_cnt():
         cpu_cnt_to_use = 1
     return cpu_cnt, cpu_cnt_to_use
 
+
 def remove_a_folder(folder_dir: str):
     """Helper to remove a directory"""
     shutil.rmtree(folder_dir, ignore_errors=True)
 
-def determine_chunksize_for_imap(data_df_len: int=None,
+
+def determine_chunksize_for_imap(data_df_len: int = None,
                                  percent: float = 0.025):
     if data_df_len < 100:
         return 10
     else:
-        ratio = int(data_df_len *  percent)
+        ratio = int(data_df_len * percent)
         if ratio > 200:
             ratio = 200
         return ratio
 
+
 def tabulate_clf_info(clf_path: str):
     """
     Helper to print the hyper-parameters and creation date of a pickled classifier.
@@ -852,11 +875,12 @@ def tabulate_clf_info(clf_path: str):
     if creation_time != 'Unknown':
         creation_time = str(datetime.utcfromtimestamp(creation_time).strftime('%Y-%m-%d %H:%M:%S'))
 
-
     print(str(clf_name), "CLASSIFIER INFORMATION")
-    for (name, val) in zip(['NUMBER OF FEATURES', 'NUMBER OF TREES', 'CLASSIFIER CRITERION', 'CLASSIFIER_MIN_SAMPLE_LEAF',
-              'CLASSIFIER_N_JOBS', 'CLASSIFIER VERBOSE SETTING', 'CLASSIFIER PATH', 'CLASSIFIER CREATION TIME'], [clf_features_no, clf_estimators, clf_criterion, clf_min_samples_leaf,
-                                                                   clf_n_jobs, clf_verbose, clf_path, str(creation_time)]):
+    for (name, val) in zip(
+            ['NUMBER OF FEATURES', 'NUMBER OF TREES', 'CLASSIFIER CRITERION', 'CLASSIFIER_MIN_SAMPLE_LEAF',
+             'CLASSIFIER_N_JOBS', 'CLASSIFIER VERBOSE SETTING', 'CLASSIFIER PATH', 'CLASSIFIER CREATION TIME'],
+            [clf_features_no, clf_estimators, clf_criterion, clf_min_samples_leaf,
+             clf_n_jobs, clf_verbose, clf_path, str(creation_time)]):
         print(name + ': ' + str(val))
 
 
@@ -906,6 +930,7 @@ def convert_parquet_to_csv(directory: str):
         print('Saved {}...'.format(new_file_path))
     print('SIMBA COMPLETE: {} parquet files in {} converted to csv'.format(str(len(files_found)), directory))
 
+
 def convert_csv_to_parquet(directory: str):
     """
     Helper to convert all csv files in a folder to parquet format.
@@ -951,7 +976,8 @@ def archive_processed_files(config_path: str,
 
     config = read_config_file(config_path)
     file_type = read_config_entry(config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.FILE_TYPE.value, 'str', 'csv')
-    project_path = read_config_entry(config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value, data_type=ReadConfig.FOLDER_PATH.value)
+    project_path = read_config_entry(config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value,
+                                     data_type=ReadConfig.FOLDER_PATH.value)
     videos_dir = os.path.join(project_path, 'videos')
     csv_dir = os.path.join(os.path.dirname(config_path), 'csv')
     log_path = os.path.join(project_path, 'logs')
@@ -969,7 +995,9 @@ def archive_processed_files(config_path: str,
                 file_lst.append(os.path.join(subdirectory, file_path))
 
     if len(file_lst) < 1:
-        print('SIMBA ERROR: No data files located in your project_folder/csv sub-directories in the worflow file format {}'.format(file_type))
+        print(
+            'SIMBA ERROR: No data files located in your project_folder/csv sub-directories in the worflow file format {}'.format(
+                file_type))
         raise ValueError()
 
     for file_path in file_lst:
@@ -996,6 +1024,7 @@ def archive_processed_files(config_path: str,
 
     print('SIMBA COMPLETE: Archiving completed.')
 
+
 def get_color_dict():
     return {'Grey': (220, 200, 200),
             'Red': (0, 0, 255),
@@ -1016,6 +1045,7 @@ def get_color_dict():
             'White': (255, 255, 255),
             'Black': (0, 0, 0)}
 
+
 def get_named_colors():
     return ['red',
             'black',
@@ -1039,9 +1069,11 @@ def get_named_colors():
             'deeppink',
             'white']
 
+
 class SimbaTimer(object):
     def start_timer(self):
         self.timer = time.time()
+
     def stop_timer(self):
         if not hasattr(self, 'timer'):
             self.elapsed_time = -1
@@ -1053,8 +1085,8 @@ class SimbaTimer(object):
 
 def concatenate_videos_in_folder(in_folder: str,
                                  save_path: str,
-                                 video_format: str='mp4',
-                                 remove_splits: bool=True) -> None:
+                                 video_format: str = 'mp4',
+                                 remove_splits: bool = True) -> None:
     """
     Helper to  concatenate (temporally) all video files in a folder into a
     single video.
@@ -1071,14 +1103,16 @@ def concatenate_videos_in_folder(in_folder: str,
     timer.start_timer()
     files = glob.glob(in_folder + '/*.{}'.format(video_format))
     check_if_filepath_list_is_empty(filepaths=files,
-                                    error_msg='SIMBA ERROR: Cannot join videos in {}. The directory contain ZERO files.'.format(in_folder))
+                                    error_msg='SIMBA ERROR: Cannot join videos in {}. The directory contain ZERO files.'.format(
+                                        in_folder))
     files.sort(key=lambda f: int(re.sub('\D', '', f)))
     temp_txt_path = pathlib.Path(in_folder, 'files.txt')
     with open(temp_txt_path, 'w') as f:
         for file in files:
             f.write("file '" + str(pathlib.Path(file)) + "'\n")
     if os.path.exists(save_path): os.remove(save_path)
-    returned = os.system('ffmpeg -f concat -safe 0 -i "{}" "{}" -c copy -hide_banner -loglevel info'.format(temp_txt_path, save_path))
+    returned = os.system(
+        'ffmpeg -f concat -safe 0 -i "{}" "{}" -c copy -hide_banner -loglevel info'.format(temp_txt_path, save_path))
     while True:
         if returned != 0:
             pass
@@ -1089,8 +1123,9 @@ def concatenate_videos_in_folder(in_folder: str,
     timer.stop_timer()
     print('Video concatenated (elapsed time: {}s)'.format(timer.elapsed_time_str))
 
+
 def find_all_videos_in_directory(directory: str,
-                                 as_dict: bool=False,
+                                 as_dict: bool = False,
                                  video_formats: tuple = ('.avi', '.mp4', '.mov', '.flv', '.m4v')):
     """
     Helper to return list of all video file paths in a directory
@@ -1109,7 +1144,6 @@ def find_all_videos_in_directory(directory: str,
     list or dict
     """
 
-
     video_lst = []
     for i in os.listdir(directory):
         if i.lower().endswith(video_formats):
@@ -1118,7 +1152,6 @@ def find_all_videos_in_directory(directory: str,
         video_lst.append('No videos found')
         print('SIMBA WARNING: No videos found in directory ({})'.format(directory))
 
-
     if video_lst and as_dict:
         video_dict = {}
         for video_name in video_lst:
@@ -1134,8 +1167,7 @@ def find_all_videos_in_directory(directory: str,
 def framewise_euclidean_distance(location_1: np.array,
                                  location_2: np.array,
                                  px_per_mm: float,
-                                 centimeter: bool=False) -> np.array:
-
+                                 centimeter: bool = False) -> np.array:
     results = np.full((location_1.shape[0]), np.nan)
     for i in prange(location_1.shape[0]):
         results[i] = np.linalg.norm(location_1[i] - location_2[i]) / px_per_mm
@@ -1143,10 +1175,10 @@ def framewise_euclidean_distance(location_1: np.array,
         results = results / 10
     return results
 
+
 def copy_single_video_to_project(simba_ini_path: str,
                                  source_path: str,
                                  allowed_video_formats: tuple = ('avi', 'mp4')) -> None:
-
     """ Helper to import single video file to SimBA project
     Parameters
     ----------
@@ -1163,17 +1195,22 @@ def copy_single_video_to_project(simba_ini_path: str,
     _, file_name, file_ext = get_fn_ext(source_path)
     print('Copying video {} file...'.format(file_name))
     if file_ext[1:].lower().strip() not in allowed_video_formats:
-        print('SIMBA ERROR: SimBA works best with avi and mp4 videofiles. Or please convert your videos to mp4 or avi to continue before importing it. ')
+        print(
+            'SIMBA ERROR: SimBA works best with avi and mp4 videofiles. Or please convert your videos to mp4 or avi to continue before importing it. ')
         raise ValueError()
     new_filename = os.path.join(file_name + file_ext)
     destination = os.path.join(os.path.dirname(simba_ini_path), 'videos', new_filename)
     if os.path.isfile(destination):
-        print('SIMBA ERROR: {} already exist in SimBA project. To import, delete this video file before importing the new video file with the same name.'.format(file_name))
+        print(
+            'SIMBA ERROR: {} already exist in SimBA project. To import, delete this video file before importing the new video file with the same name.'.format(
+                file_name))
         raise FileExistsError()
     else:
         timer.stop_timer()
         shutil.copy(source_path, destination)
-        print('SIMBA COMPLETE: Video {} imported to SimBA project (project_folder/videos directory, elapsed time: {}s).'.format(file_name, timer.elapsed_time_str))
+        print(
+            'SIMBA COMPLETE: Video {} imported to SimBA project (project_folder/videos directory, elapsed time: {}s).'.format(
+                file_name, timer.elapsed_time_str))
 
 
 def copy_multiple_videos_to_project(config_path: str,
@@ -1196,7 +1233,8 @@ def copy_multiple_videos_to_project(config_path: str,
     """
 
     if file_type.lower().strip() not in allowed_video_formats:
-        print('SIMBA ERROR: SimBA only works with avi and mp4 videofiles (Please enter mp4 or avi in entrybox). Or please convert your videos to mp4 or avi to continue. ')
+        print(
+            'SIMBA ERROR: SimBA only works with avi and mp4 videofiles (Please enter mp4 or avi in entrybox). Or please convert your videos to mp4 or avi to continue. ')
         raise ValueError()
     video_path_lst = find_all_videos_in_directory(directory=source, video_formats=(file_type))
     video_path_lst = [os.path.join(source, x) for x in video_path_lst]
@@ -1223,7 +1261,6 @@ def copy_multiple_videos_to_project(config_path: str,
     print('SIMBA COMPLETE: {} videos copied to project.'.format(str(len(video_path_lst))))
 
 
-
 def get_file_name_info_in_directory(directory: str,
                                     file_type: str):
     """
@@ -1242,7 +1279,6 @@ def get_file_name_info_in_directory(directory: str,
     video_lst: list
     """
 
-
     results = {}
     file_paths = glob.glob(directory + "/*." + file_type)
     for file_path in file_paths:
@@ -1254,8 +1290,7 @@ def get_file_name_info_in_directory(directory: str,
 
 def split_and_group_df(df: pd.DataFrame,
                        splits: int,
-                       include_split_order: bool=True):
-
+                       include_split_order: bool = True):
     data_arr = np.array_split(df, splits)
     if include_split_order:
         for df_cnt in range(len(data_arr)):
@@ -1267,7 +1302,7 @@ def split_and_group_df(df: pd.DataFrame,
 
 def find_files_of_filetypes_in_directory(directory: str,
                                          extensions: list,
-                                         raise_warning: bool=True):
+                                         raise_warning: bool = True):
     """
     Helper to find all files in a folder with specified extensions
 
@@ -1286,7 +1321,8 @@ def find_files_of_filetypes_in_directory(directory: str,
     try:
         all_files_in_folder = [f for f in next(os.walk(directory))[2] if not f[0] == '.']
     except StopIteration:
-        print('SIMBA WARNING: No files found in the {} directory with accepted extensions {}'.format(directory, str(extensions)))
+        print('SIMBA WARNING: No files found in the {} directory with accepted extensions {}'.format(directory,
+                                                                                                     str(extensions)))
         raise FileNotFoundError('SIMBA ERROR: No files found in the directory with accepted extensions')
     all_files_in_folder = [os.path.join(directory, x) for x in all_files_in_folder]
     accepted_file_paths = []
@@ -1295,10 +1331,12 @@ def find_files_of_filetypes_in_directory(directory: str,
         if ext.lower() in extensions:
             accepted_file_paths.append(file_path)
     if not accepted_file_paths and raise_warning:
-        print('SIMBA WARNING: SimBA could not find any files with accepted extensions {} in the {} directory'.format(extensions, str(directory)))
+        print('SIMBA WARNING: SimBA could not find any files with accepted extensions {} in the {} directory'.format(
+            extensions, str(directory)))
 
     return accepted_file_paths
 
+
 def get_feature_extraction_headers(pose: str):
     """ Helper to return the headers names that should be used during feature extraction"""
     simba_dir = os.path.dirname(simba.__file__)
@@ -1306,3 +1344,42 @@ def get_feature_extraction_headers(pose: str):
     check_file_exist_and_readable(file_path=feature_categories_csv_path)
     bps = list(pd.read_csv(feature_categories_csv_path)[pose])
     return [x for x in bps if str(x) != 'nan']
+
+
+def run_user_defined_feature_extraction_class(file_path: str,
+                                              config_path: str):
+    """
+    Parameters
+    ----------
+    file_path: str
+        Path to .py file holding user-defined feature extraction class
+    config_path: str
+        Path to SimBA cproject config file
+    """
+
+    check_file_exist_and_readable(file_path=file_path)
+    file_dir, file_name, file_extension = get_fn_ext(filepath=file_path)
+    if file_extension != '.py':
+        print(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) is not a .py file-extension')
+        raise ImportError(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) is not a .py file-extension')
+    parsed = ast.parse(Path(file_path).read_text())
+    classes = [n for n in parsed.body if isinstance(n, ast.ClassDef)]
+    class_name = [x.name for x in classes]
+    if len(class_name) < 1:
+        print(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) contains no python classes')
+        raise ImportError(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) contains no python classes')
+    else:
+        class_name = class_name[0]
+    spec = importlib.util.spec_from_file_location(class_name, file_path)
+    user_module = importlib.util.module_from_spec(spec)
+    sys.modules[class_name] = user_module
+    spec.loader.exec_module(user_module)
+    user_class = getattr(user_module, class_name)
+    print(f'Running user-defined {class_name} feature extraction file...')
+    user_class(config_path=config_path)
+
+
+
+# run_user_defined_feature_extraction_class(file_path='/Users/simon/Desktop/envs/simba_dev/simba/features_scripts/misc/fish_feature_extractor.py',
+#                                           config_path='/Users/simon/Desktop/envs/simba_dev/tests/test_data/zebrafish/project_folder/project_config.ini')
+
