@@ -124,12 +124,12 @@ class PathPlotterMulticore(object):
                  files_found: list,
                  style_attr: dict or None,
                  animal_attr: dict,
-                 clf_attr: dict,
+                 clf_attr: dict or None,
                  cores: int):
 
 
-        if platform.system() == "Darwin":
-            multiprocessing.set_start_method('spawn', force=True)
+        # if platform.system() == "Darwin":
+        #     multiprocessing.set_start_method('spawn', force=True)
 
         self.video_setting, self.frame_setting, self.style_attr, self.files_found, self.animal_attr, self.clf_attr, self.last_frame, self.cores = video_setting, frame_setting, style_attr, files_found, animal_attr, clf_attr, last_frame, cores
         if (not frame_setting) and (not video_setting) and (not last_frame):
@@ -202,7 +202,7 @@ class PathPlotterMulticore(object):
                     bp_x_name = '{}_{}'.format(animal_data[0], 'x')
                     bp_y_name = '{}_{}'.format(animal_data[0], 'y')
                     data_arr = np.hstack((data_arr, self.data_df[[bp_x_name, bp_y_name]].astype(int).values))
-                    if animal_cnt == 0:
+                    if animal_cnt == 0 and self.clf_attr:
                         self.clf_attr['positions'] = deepcopy(data_arr[:, 1:3])
                 data_arr = self.__split_array_into_max_lines(data=data_arr, max_lines=self.style_attr['max lines'])
                 data_arr = np.array_split(data_arr, self.cores)
@@ -311,11 +311,12 @@ class PathPlotterMulticore(object):
 # animal_attr = {0: ['Ear_right_1', 'Red'], 1: ['Ear_right_2', 'Yellow']}
 # clf_attr = {0: ['Attack', 'Black', 'Size: 30'], 1: ['Sniffing', 'Red', 'Size: 30']}
 #
+# clf_attr = None
 # style_attr = None
 #
 # path_plotter = PathPlotterMulticore(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini',
 #                                     frame_setting=False,
-#                                     video_setting=False,
+#                                     video_setting=True,
 #                                     last_frame=True,
 #                                     clf_attr=clf_attr,
 #                                     style_attr=style_attr,
