@@ -13,21 +13,19 @@ def check_int(name, value, max_value=None, min_value=None):
         t.Int().check(value)
     except t.DataError as e:
         print('SIMBA VALUE ERROR: {} {} {}'.format(name, str(value), e.as_dict()))
-        raise ValueError('SIMBA VALUE ERROR: {} should be an integer number in SimBA, but is set to {}'.format(name, str(value)))
+        raise ValueError(f'SIMBA VALUE ERROR: {name} should be an integer number in SimBA, but is set to {str(value)}')
     if (min_value != None):
         if int(value) < min_value:
             print(('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
                                                                                               str(value))))
             raise ValueError(
-                'SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
-                                                                                           str(value)))
+                f'SIMBA VALUE ERROR: {name} should be more than, or equal {str(min_value)}. It is set to {str(value)}')
     if (max_value != None):
         if int(value) > max_value:
             print(('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
                                                                                               str(value))))
             raise ValueError(
-                'SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
-                                                                                           str(value)))
+                f'SIMBA VALUE ERROR: {name} should be less than, or equal {str(max_value)}. It is set to {str(value)}')
 
 def check_if_valid_input(name, input, options):
     if input not in options:
@@ -49,8 +47,7 @@ def check_str(name, value, options=(), allow_blank=False):
             print(('SIMBA VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
                                                                                                      options)))
             raise ValueError(
-                'SIMBA VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
-                                                                                                  options))
+                f'SIMBA VALUE ERROR: {name} is set to {str(value)} in SimBA, but this is not a valid option {options}')
         else:
             pass
     else:
