@@ -6,12 +6,16 @@ import cv2
 from simba.roi_tools.ROI_image import ROI_image_class
 import pandas as pd
 from simba.tkinter_functions import hxtScrollbar
-from simba.roi_tools.ROI_move_shape import update_all_tags, move_edge
+from simba.roi_tools.ROI_move_shape import (update_all_tags, move_edge)
 from simba.roi_tools.ROI_multiply import create_emty_df
-from simba.roi_tools.ROI_size_calculations import rectangle_size_calc, circle_size_calc, polygon_size_calc
+from simba.roi_tools.ROI_size_calculations import (rectangle_size_calc,
+                                                   circle_size_calc,
+                                                   polygon_size_calc)
+from simba.misc_tools import get_color_dict
 from simba.features_scripts.unit_tests import read_video_info
 from simba.drop_bp_cords import get_fn_ext
 from simba.features_scripts.unit_tests import read_video_info_csv
+from simba.enums import Paths, ReadConfig
 
 
 class ROI_definitions:
@@ -44,12 +48,12 @@ class ROI_definitions:
         config.read(config_path)
         self.video_path = video_path
         _, self.file_name, self.file_ext = get_fn_ext(self.video_path)
-        self.project_path = config.get('General settings', 'project_path')
+        self.project_path = config.get(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value)
         self.roi_data_folder = os.path.join(self.project_path, 'logs', 'measures')
         if not os.path.exists(self.roi_data_folder):
             os.makedirs(self.roi_data_folder)
         self.store_fn = os.path.join(self.roi_data_folder, 'ROI_definitions.h5')
-        self.video_info_path = os.path.join(self.project_path, 'logs', 'video_info.csv')
+        self.video_info_path = os.path.join(self.project_path, Paths.VIDEO_INFO.value)
         self.video_folder_path = os.path.join(self.project_path, 'videos')
         self.other_video_paths = glob.glob(self.video_folder_path + '/*.mp4') + glob.glob(self.video_folder_path + '/*.avi')
         self.other_video_paths.remove(video_path)
@@ -90,23 +94,7 @@ class ROI_definitions:
         self.text_size = 5
         self.text_thickness = 3
         self.line_type = -1
-        self.named_shape_colors = {'White': (255, 255, 255),
-                                   'Grey': (220, 200, 200),
-                                   'Red': (0, 0, 255),
-                                   'Dark-red': (0, 0, 139),
-                                   'Maroon': (0, 0, 128),
-                                   'Orange': (0, 165, 255),
-                                   'Dark-orange': (0, 140, 255),
-                                   'Coral': (80, 127, 255),
-                                   'Chocolate': (30, 105, 210),
-                                   'Yellow': (0, 255, 255),
-                                   'Green': (0, 128, 0),
-                                   'Dark-grey': (105, 105, 105),
-                                   'Light-grey': (192, 192, 192),
-                                   'Pink': (178, 102, 255),
-                                   'Lime': (204, 255, 229),
-                                   'Purple': (255, 51, 153),
-                                   'Cyan': (255, 255, 102)}
+        self.named_shape_colors = get_color_dict()
         self.window_menus()
         self.master.lift()
         self.master = Canvas(hxtScrollbar(self.master))
