@@ -18,8 +18,8 @@ from simba.drop_bp_cords import create_body_part_dictionary, getBpNames
 import os, glob
 from simba.rw_dfs import read_df
 from simba.drop_bp_cords import get_fn_ext
-from numba import jit
-import numpy as np
+import seaborn as sns
+import matplotlib.pyplot as plt
 import itertools
 
 
@@ -44,13 +44,14 @@ class TimeBinsMovementAnalyzer(object):
 
     def __init__(self,
                  config_path: str,
-                 bin_length: int):
+                 bin_length: int,
+                 plots: bool):
 
         self.timer = SimbaTimer()
         self.timer.start_timer()
         self.bin_length = bin_length
         self.config = read_config_file(config_path)
-        self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
+        self.datetime, self.plots = datetime.now().strftime('%Y%m%d%H%M%S'), plots
         self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
         self.data_in_dir = os.path.join(self.project_path, Paths.OUTLIER_CORRECTED.value)
         self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
@@ -70,6 +71,19 @@ class TimeBinsMovementAnalyzer(object):
         self.animal_combinations = list(itertools.combinations(self.animal_bp_dict, 2))
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
 
+    def __create_plots(self):
+        print('Creating time-bin movement plots...')
+        self.video_df['Time bin #'] = self.video_df['Time bin #'].astype(str)
+        plots_dir = os.path.join(self.project_path, 'logs', f'time_bin_movement_plots_{self.datetime}')
+        if not os.path.exists(plots_dir): os.makedirs(plots_dir)
+        for video_name in self.video_df.index.unique():
+            video_df = self.video_df[self.video_df.index == video_name].reset_index(drop=True)
+            video_movement_df = video_df[video_df['Measurement'].isin(list(self.movement_cols))]
+            line_plot = sns.lineplot(data=video_movement_df, x="Time bin #", y="Value", hue='Measurement')
+            line_plot.figure.savefig(os.path.join(plots_dir, f'{video_name}.png'))
+            plt.close()
+        print(f'Time bin movement plots saved in {plots_dir}...')
+
     def analyze_movement(self):
         """
         Method for running the movement time-bin analysis. Results are stored in the ``project_folder/logs`` directory
@@ -79,14 +93,16 @@ class TimeBinsMovementAnalyzer(object):
         ----------
         None
         """
-        video_dict = {}
-        self.out_df_lst = []
+        video_dict, self.out_df_lst = {}, []
         for file_cnt, file_path in enumerate(self.files_found):
-            result_df = pd.DataFrame()
+            video_timer = SimbaTimer()
+            video_timer.start_timer()
             _, video_name, _ = get_fn_ext(file_path)
+            print(f'Processing time-bin movements for video {video_name} ({str(file_cnt+1)}/{str(len(self.files_found))})...')
+            result_df = pd.DataFrame()
             video_dict[video_name] = {}
             video_settings, px_per_mm, fps = read_video_info(vid_info_df=self.vid_info_df, video_name=video_name)
-            fps = int(fps)
+            fps, self.movement_cols, self.velocity_cols = int(fps), set(), set()
             bin_length_frames = int(fps * self.bin_length)
             data_df = read_df(file_path, self.file_type)
             data_df_sliced = pd.DataFrame()
@@ -114,8 +130,8 @@ class TimeBinsMovementAnalyzer(object):
             results_df_lists = [result_df[i:i + bin_length_frames] for i in range(0, result_df.shape[0], bin_length_frames)]
             indexed_df_lst = []
             for bin, results in enumerate(results_df_lists):
-                timbe_bin_per_s = [results[i:i + fps] for i in range(0, results.shape[0], fps)]
-                for second, df in enumerate(timbe_bin_per_s):
+                time_bin_per_s = [results[i:i + fps] for i in range(0, results.shape[0], fps)]
+                for second, df in enumerate(time_bin_per_s):
                     df['Time bin #'], df['Second'] = bin, second
                     indexed_df_lst.append(df)
             indexed_df = pd.concat(indexed_df_lst, axis=0)
@@ -126,9 +142,13 @@ class TimeBinsMovementAnalyzer(object):
                 movement_velocity = indexed_df.groupby(['Time bin #', 'Second'])[movement_col].sum().reset_index()
                 movement_velocity = movement_velocity.groupby(['Time bin #'])[movement_col].mean().reset_index()
                 video_dict[video_name][movement_col + ' (cm)'] = movement_sum
-                video_dict[video_name][movement_col+ ' velocity (cm/s)'] = movement_velocity
+                self.movement_cols.add(movement_col + ' (cm)')
+                video_dict[video_name][movement_col + ' velocity (cm/s)'] = movement_velocity
+                self.velocity_cols.add(movement_col + ' velocity (cm/s)')
             for distance_col in distance_cols:
                 video_dict[video_name][distance_col + ' (cm)'] = indexed_df.groupby(['Time bin #'])[distance_col].mean().reset_index()
+            video_timer.stop_timer()
+            print(f'Video {video_name} complete (elapsed time: {video_timer.elapsed_time_str}s)...')
 
         for video_name, video_info in video_dict.items():
             for measurement, bin_data in video_info.items():
@@ -138,11 +158,15 @@ class TimeBinsMovementAnalyzer(object):
                 data_df.insert(loc=0, column='Measurement', value=measurement)
                 data_df.insert(loc=0, column='Video', value=video_name)
                 self.out_df_lst.append(data_df)
-        video_df = pd.concat(self.out_df_lst, axis= 0).sort_values(by=['Video', 'Time bin #']).set_index('Video')
+        self.video_df = pd.concat(self.out_df_lst, axis= 0).sort_values(by=['Video', 'Time bin #']).set_index('Video')
+        if self.plots:
+            self.__create_plots()
+
         save_path = os.path.join(self.project_path, 'logs', 'Time_bins_movement_results_' + self.datetime + '.csv')
-        video_df.to_csv(save_path)
+        self.video_df.to_csv(save_path)
         self.timer.stop_timer()
         print('SIMBA COMPLETE: Movement time-bins results saved at {} (elapsed time: {}s)'.format(save_path, self.timer.elapsed_time_str))
 
-# test = TimeBinsMovementAnalyzer(config_path='/Users/simon/Desktop/envs/troubleshooting/Two_animals_16bps/project_folder/project_config.ini', bin_length=20)
+# test = TimeBinsMovementAnalyzer(config_path='/Users/simon/Desktop/envs/troubleshooting/Vince_time_bins/project_folder/project_config.ini',
+#                                 bin_length=60, plots=True)
 # test.analyze_movement()
\ No newline at end of file
