@@ -69,8 +69,8 @@ def read_all_files_in_folder(file_paths: list,
         if classifier_names != None:
             for clf_name in classifier_names:
                 if not clf_name in df.columns:
-                    print('SIMBA ERROR: Data for video {} does not contain any annotations for behavior {}. Delete classifier {} from the SimBA project, or add annotations for behavior {} to the video {}'.format(vid_name, clf_name, clf_name, clf_name, vid_name))
-                    raise ValueError('SIMBA ERROR: Data for video {} does not contain any annotations for behavior {}. Delete classifier {} from the SimBA project, or add annotations for behavior {} to the video {}'.format(vid_name, clf_name, clf_name, clf_name, vid_name))
+                    print(f'SIMBA ERROR: Data for video {vid_name} does not contain any annotations for behavior {clf_name}. Delete classifier {clf_name} from the SimBA project, or add annotations for behavior {clf_name} to the video {vid_name}')
+                    raise ValueError(f'SIMBA ERROR: Data for video {vid_name} does not contain any annotations for behavior {clf_name}. Delete classifier {clf_name} from the SimBA project, or add annotations for behavior {clf_name} to the video {vid_name}')
                 else:
                     df_concat = pd.concat([df_concat, df], axis=0)
         else:
@@ -177,7 +177,7 @@ def random_undersampler(x_train: np.array,
     df: pd.DataFrame
     """
 
-    print('Performing under-sampling...')
+    print(f'Performing under-sampling at sample ratio {str(sample_ratio)}...')
     data_df = pd.concat([x_train, y_train], axis=1)
     present_df, absent_df = data_df[data_df[y_train.name] == 1], data_df[data_df[y_train.name] == 0]
     ratio_n = int(len(present_df) * sample_ratio)
@@ -201,17 +201,17 @@ def smoteen_oversampler(x_train: pd.DataFrame,
 
     Parameters
     ----------
-    x_train: pd.DataFrame or np.array
+    x_train: pd.DataFrame or array
         pandas Dataframe holding features and annotations.
-    y_train: pd.DataFrame or np.array
+    y_train: pd.DataFrame or array
         List of column fields to be removed from df
     sample_ratio:
         New behavior-present frames.
 
     Returns
     -------
-    x_train: np.array
-    y_train: np.array
+    x_train: array
+    y_train: array
 
     """
 
@@ -278,7 +278,7 @@ def calc_permutation_importance(x_test: np.array,
     print('Calculating feature permutation importances...')
     timer = SimbaTimer()
     timer.start_timer()
-    p_importances = permutation_importance(clf, x_test, y_test, n_repeats=10, random_state = 0)
+    p_importances = permutation_importance(clf, x_test, y_test, n_repeats=10, random_state=0)
     df = pd.DataFrame(np.column_stack([feature_names, p_importances.importances_mean, p_importances.importances_std]), columns=['FEATURE_NAME', 'FEATURE_IMPORTANCE_MEAN', 'FEATURE_IMPORTANCE_STDEV'])
     df = df.sort_values(by=['FEATURE_IMPORTANCE_MEAN'], ascending=False)
     if save_file_no != None:
@@ -896,7 +896,6 @@ def insert_column_headers_for_outlier_correction(data_df: pd.DataFrame,
         data_df.columns = new_headers
         return data_df
 
-
 def read_pickle(file_path: str) -> object:
     try:
         clf = pickle.load(open(file_path, 'rb'))
@@ -906,7 +905,6 @@ def read_pickle(file_path: str) -> object:
     return clf
 
 
-
 def bout_train_test_splitter(x_df: pd.DataFrame,
                              y_df: pd.Series,
                              test_size: float):
@@ -944,8 +942,9 @@ def bout_train_test_splitter(x_df: pd.DataFrame,
 
     test_bouts_frames, train_bouts_frames = find_bouts(s=y_df, type='behavior present')
     test_nonbouts_frames, train_nonbouts_frames = find_bouts(s=np.logical_xor(y_df, 1).astype(int), type='behavior absent')
-    x_train = x_df[x_df.index.isin(train_bouts_frames + train_nonbouts_frames)].values
-    x_test = x_df[x_df.index.isin(test_bouts_frames + test_nonbouts_frames)].values
-    y_train = y_df[y_df.index.isin(train_bouts_frames + train_nonbouts_frames)].values
-    y_test = y_df[y_df.index.isin(test_bouts_frames + test_nonbouts_frames)].values
+    x_train = x_df[x_df.index.isin(train_bouts_frames + train_nonbouts_frames)]
+    x_test = x_df[x_df.index.isin(test_bouts_frames + test_nonbouts_frames)]
+    y_train = y_df[y_df.index.isin(train_bouts_frames + train_nonbouts_frames)]
+    y_test = y_df[y_df.index.isin(test_bouts_frames + test_nonbouts_frames)]
+
     return x_train, x_test, y_train, y_test
\ No newline at end of file
