@@ -87,10 +87,18 @@ def clahe_enhance_video(file_path: str):
                 clahe_frm = clahe_filter.apply(img)
                 writer.write(clahe_frm)
                 print('CLAHE converted frame {}/{}'.format(str(frm_cnt), str(video_meta_data['frame_count'])))
+            else:
+                cap.release()
+                writer.release()
     except Exception as se:
         print(se.args)
         print('CLAHE conversion failed for video {}'.format(file_name))
-        raise ValueError
+        cap.release()
+        writer.release()
+        raise ValueError()
+
+
+
 
 
 def extract_frame_range(file_path: str,
